;; Generated package description from beframe.el  -*- no-byte-compile: t -*-
(define-package "beframe" "0.1.11.0.20230327.54408" "Isolate buffers per frame" '((emacs "28.1")) :commit "534f11d36964a3094595c29b470a324a2296e2b1" :authors '(("Protesilaos Stavrou" . "info@protesilaos.com")) :maintainer '("Protesilaos Stavrou General Issues" . "~protesilaos/general-issues@lists.sr.ht") :url "https://git.sr.ht/~protesilaos/beframe")
